<p align="center">
    <em>jaanca public libraries</em>
</p>

<p align="center">
<a href="https://pypi.org/project/jaanca" target="_blank">
    <img src="https://img.shields.io/pypi/v/jaanca?color=blue&label=PyPI%20Package" alt="Package version">
</a>
<a href="(https://www.python.org" target="_blank">
    <img src="https://img.shields.io/badge/Python-%5B%3E%3D3.8%2C%3C%3D3.11%5D-blue" alt="Python">
</a>
</p>


---

#  A tool library created by jaanca

[Source code](https://github.com/jaanca/python-libraries/tree/main/jaanca)
| [Package (PyPI)](https://pypi.org/project/jaanca/)

---

# Here is a non-exhaustive list of related packages:

- [jaanca-chronometer](https://pypi.org/project/jaanca-chronometer/) : jaanca's helper chronometer